@@ -42,10 +42,6 @@ sanitize_control <- function(control) {
     cont
 }
 
-as.bound <- function( x, ... ) UseMethod( "as.bound" )
-as.bound.bound <- identity
-as.bound.NULL <- function( x, ... ) structure(list(), class="bound")
-
 ## get the indices of the conic bounds which are not the free cone
 get_indizes_nonfree <- function(bo) {
     if ( is.null(bo) )
